@@ -10,6 +10,8 @@ pub enum ArgVal {
 pub struct Arg {
     /// Name of the argument
     pub (crate) name: String,
+    /// Option long (string) value of the argument
+    pub (crate) long: Option<String>,
     /// Optional short (char) value of the argument
     pub (crate) short: Option<char>,
     /// Help string for the argument
@@ -23,6 +25,7 @@ impl Arg {
     pub fn bool(name: &str, val: bool) -> Self {
         Self {
             name: String::from(name),
+            long: None,
             short: None,
             help: String::new(),
             val: ArgVal::Bool(val),
@@ -33,12 +36,19 @@ impl Arg {
     pub fn str(name: &str, val: &str) -> Self {
         Self {
             name: String::from(name),
+            long: None,
             short: None,
             help: String::new(),
             val: ArgVal::Str(String::from(val)),
         }
     }
 
+    /// Sets the long value of the argument
+    pub fn long(&mut self, long: &str) -> &mut Self {
+        self.long = Some(String::from(long));
+        self
+    }
+
     /// Sets the short value of the argument
     pub fn short(&mut self, short: char) -> &mut Self {
         self.short = Some(short);
