@@ -47,10 +47,10 @@ impl ArgParser {
 
         s.args(vec!(
             Arg::bool("help", false)
-                .short('h')
+            	.long("help")
                 .help("Prints this dialogue"),
             Arg::bool("version", false)
-                .short('v')
+            	.long("version")
                 .help("Prints the version"),
         ));
 
@@ -81,9 +81,10 @@ impl ArgParser {
         self
     }
 
-    /// Sets the usage
+    /// Sets the usage. Replaces all instances of {name} with the program's name.
     pub fn usage(&mut self, s: &str) -> &mut Self {
-        self.usage = String::from(s);
+        self.usage = s.replace("{name}", &self.name);
+        //self.usage = String::from(s);
         self
     }
 
@@ -104,16 +105,14 @@ impl ArgParser {
     fn set_arg(skip: &mut bool, arg: &mut Arg, next: Option<&String>) {
         if let ArgVal::Bool(b) = arg.val {
             arg.val = ArgVal::Bool(!b);
-        } else {
-            if let Some(next) = next {
-                if next.starts_with("--") || next.starts_with('-') {
-                    Self::error_exit(&format!("argument \"{}\" where value for \"{}\" should be", next, arg.name));
-                }
-                arg.val = ArgVal::Str(next.to_owned());
-                *skip = true;
-            } else {
-                    Self::error_exit(&format!("expected value for argument \"{}\"", arg.name));
+        } else if let Some(next) = next {
+            if next.starts_with("--") || next.starts_with('-') {
+                Self::error_exit(&format!("argument \"{}\" where value for \"{}\" should be", next, arg.name));
             }
+            arg.val = ArgVal::Str(next.to_owned());
+            *skip = true;
+        } else {
+            Self::error_exit(&format!("expected value for argument \"{}\"", arg.name));
         }
     }
 
@@ -151,7 +150,7 @@ impl ArgParser {
 
     /// Parses a given Vec<String>
     pub fn parse_vec(&mut self, args: Vec<String>) -> &mut Self {
-        if args.len() == 0 && self.require_args {
+        if args.is_empty() && self.require_args {
             self.help_exit();
         }
         let mut skip = false;
@@ -160,7 +159,8 @@ impl ArgParser {
             if let Some(arg) = arg.strip_prefix("--") {
                 let mut exists = false;
                 self.args.iter_mut()
-                    .filter(|parg| parg.name == arg)
+                    .filter(|parg| parg.long != None)
+                    .filter(|parg| parg.long.as_ref().unwrap() == arg)
                     .for_each(|mut parg| {Self::set_arg(&mut skip, &mut parg, args.get(idx+1)); exists = true});
                 if !exists {Self::error_exit(&format!("unexpected argument \"{}\"", arg));}
             } else if let Some(arg) = arg.strip_prefix('-') {
@@ -194,7 +194,7 @@ impl ArgParser {
 
         let mut flags = Vec::new();
         let mut options = Vec::new();
-        &self.args.iter().for_each(|arg| {
+        self.args.iter().for_each(|arg| {
             match arg.val {
                 ArgVal::Bool(_) => flags.push(arg),
                 ArgVal::Str(_) => options.push(arg),
@@ -202,33 +202,41 @@ impl ArgParser {
         });
 
         let mut longest = 0;
-        &self.args.iter().for_each(|arg| if arg.name.len() > longest {longest = arg.name.len()});
+        self.args.iter().filter_map(|arg| arg.long.as_ref()).for_each(|l| if l.len() > longest {longest = l.len()});
         longest += 4;
 
         let print = |input: &Arg| {
             //               vv
-            let mut name = "    ".to_string();
+            let mut long = "    ".to_string();
             let mut short = "  ".to_string();
-            if input.name != "" {
-                name = format!(", --{}", input.name);
-            }
+
+            let input_long = if let Some(l) = &input.long {
+                if input.short == None {
+                    long = format!("  --{}", l);
+                } else {
+                    long = format!(", --{}", l);
+                }
+                l.clone()
+            } else {
+                String::new()
+            };
 
             if let Some(ch) = input.short {
                 short = format!("-{}", ch);
             }
 
-            print!("\t{}{}", short, name);
+            print!("\t{}{}", short, long);
 
-            for _ in input.name.len()..longest {print!(" ")}
+            for _ in input_long.len()..longest {print!(" ")}
             println!("{}", input.help);
         };
 
-        if flags.len() > 0 {
+        if flags.is_empty() {
             println!("Flags:");
             flags.iter().for_each(|f| print(f));
         }
 
-        if options.len() > 0 {
+        if options.is_empty() {
             println!("Options:");
             options.iter().for_each(|o| print(o));
         }
